netapp_ontap.models.aggregate_cloud_storage API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggregate_cloud_storage`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggregateCloudStorageSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggregateCloudStorage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `attach_eligible: bool GET`

    Specifies whether the aggregate is eligible for a cloud store to be attached.

  `migrate_threshold: Size PATCH`

    Specifies the minimum percentage of performance tier free space that must exist in order for migration of data from the capacity tier to performance tier to be allowed. Only valid for PATCH operations.

  `stores: List[CloudStorageTier] GET`

    Configuration information for each cloud storage portion of the aggregate.

  `tiering_fullness_threshold: Size PATCH`

    The percentage of space in the performance tier that must be used before data is tiered out to the cloud store. Only valid for PATCH operations.